from covid19_data.JHU import get_data
import json, urllib.request

test_url = 'https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/Coronavirus_2019_nCoV_Cases' \
           '/FeatureServer/1/query?where=1%3D1&objectIds=&time=&geometry=&geometryType=esriGeometryEnvelope&inSR' \
           '=&spatialRel=esriSpatialRelIntersects&resultType=none&distance=0.0&units=esriSRUnit_Meter&returnGeodetic' \
           '=false&outFields=&returnGeometry=true&featureEncoding=esriDefault&multipatchOption=xyFootprint' \
           '&maxAllowableOffset=&geometryPrecision=&outSR=&datumTransformation=&applyVCSProjection=false&returnIdsOnly' \
           '=false&returnUniqueIdsOnly=false&returnCountOnly=false&returnExtentOnly=false&returnQueryGeometry=false' \
           '&returnDistinctValues=false&cacheHint=false&orderByFields=&groupByFieldsForStatistics=&outStatistics=%5B%7B' \
           '%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22%3A%22Confirmed%22%2C%22outStatisticFieldName%22%3A' \
           '%22Confirmed%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22%3A%22Deaths%22%2C' \
           '%22outStatisticFieldName%22%3A%22Deaths%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22' \
           '%3A%22Recovered%22%2C%22outStatisticFieldName%22%3A%22Recovered%22%7D%5D&having=&resultOffset' \
           '=&resultRecordCount=&returnZ=false&returnM=false&returnExceededLimitFeatures=true&quantizationParameters' \
           '=&sqlFormat=none&f=pjson&token='


def test_get_data():
    data = get_data.get_data(test_url)[0]['attributes']['Confirmed']
    test_data = json.loads(urllib.request.urlopen(test_url).read().decode())['features'][0]['attributes']['Confirmed']
    assert data == test_data


def test_get_all_data():
    data = get_data.get_all_data([test_url])['Total'.upper()]['Confirmed']
    test_data = json.loads(urllib.request.urlopen(test_url).read().decode())['features'][0]['attributes']['Confirmed']
    assert data == test_data  # test comment



from .get_data import get_all_data, get_data_from_api
from ..dict_as_attribute import DictAsObj as DictToObj


class Items:
    states = {}
    countries = {}
    total = {}
    data = get_data_from_api()

    for entity in data:
        if 'Countries' == entity:
            countries.update(data[entity])
        elif 'States' == entity:
            states.update(data[entity])
        elif 'TOTAL' == entity:
            total.update(data[entity])

    data = {}
    data.update(countries)
    data.update(states)
    data.update({'Total'.upper(): total})

    def __init__(self, s):
        self.fullJSON = self.data
        self.caller = s


class Item(Items):
    def rtrn_item_json(self, name=None):
        self.json = self.fullJSON[self.caller]

    def rtrn_data(self):
        self.rtrn_item_json()
        self._confirmed()
        self._deaths()
        self._recovered()

    def _confirmed(self):
        self.confirmed = self.json['Confirmed']
        self.cases = self.confirmed

    def _deaths(self):
        self.deaths = self.json['Deaths']

    def _recovered(self):
        self.recovered = self.json['Recovered']



from covid19_data.JHU import get_object
from covid19_data.JHU import get_data

total_url = 'https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/Coronavirus_2019_nCoV_Cases' \
            '/FeatureServer/1/query?where=1%3D1&objectIds=&time=&geometry=&geometryType=esriGeometryEnvelope&inSR' \
            '=&spatialRel=esriSpatialRelIntersects&resultType=none&distance=0.0&units=esriSRUnit_Meter&returnGeodetic' \
            '=false&outFields=&returnGeometry=true&featureEncoding=esriDefault&multipatchOption=xyFootprint' \
            '&maxAllowableOffset=&geometryPrecision=&outSR=&datumTransformation=&applyVCSProjection=false&returnIdsOnly' \
            '=false&returnUniqueIdsOnly=false&returnCountOnly=false&returnExtentOnly=false&returnQueryGeometry=false' \
            '&returnDistinctValues=false&cacheHint=false&orderByFields=&groupByFieldsForStatistics=&outStatistics=%5B%7B' \
            '%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22%3A%22Confirmed%22%2C%22outStatisticFieldName%22%3A' \
            '%22Confirmed%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22%3A%22Deaths%22%2C' \
            '%22outStatisticFieldName%22%3A%22Deaths%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22' \
            '%3A%22Recovered%22%2C%22outStatisticFieldName%22%3A%22Recovered%22%7D%5D&having=&resultOffset' \
            '=&resultRecordCount=&returnZ=false&returnM=false&returnExceededLimitFeatures=true&quantizationParameters' \
            '=&sqlFormat=none&f=pjson&token='
countries_url = 'https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/ncov_cases/FeatureServer/2/query?where=1' \
                '%3D1&objectIds=&time=&geometry=&geometryType=esriGeometryEnvelope&inSR=&spatialRel=esriSpatialRelIntersects' \
                '&resultType=none&distance=0.0&units=esriSRUnit_Meter&returnGeodetic=false&outFields=+Country_Region%2C' \
                '+confirmed%2C+deaths%2C+recovered%2C+active&returnGeometry=false&featureEncoding=esriDefault' \
                '&multipatchOption=xyFootprint&maxAllowableOffset=&geometryPrecision=&outSR=&datumTransformation' \
                '=&applyVCSProjection=false&returnIdsOnly=false&returnUniqueIdsOnly=false&returnCountOnly=false' \
                '&returnExtentOnly=false&returnQueryGeometry=false&returnDistinctValues=false&cacheHint=false&orderByFields' \
                '=&groupByFieldsForStatistics=&outStatistics=&having=&resultOffset=&resultRecordCount=&returnZ=false&returnM' \
                '=false&returnExceededLimitFeatures=true&quantizationParameters=&sqlFormat=none&f=pjson&token= '
states_url = 'https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/servi' \
             'ces/ncov_cases/FeatureServer/1/query?where' \
             '=Country_Region=%27US%27&outFields=Province_State,confirmed,deaths,recovered,' \
             '%20active&resultRecordCount=200&f=pjson'


def test_Items():
    name = 'Texas'
    object = get_object.Item(name)
    assert object.data == get_data.get_all_data([total_url, countries_url, states_url])
    assert object.fullJSON == get_data.get_all_data([total_url, countries_url, states_url])
    assert name == object.caller


def test_Item():
    total = 'Total'.upper()
    state = 'Texas'.upper()
    country = 'US'.upper()

    data = get_data.get_all_data([total_url, countries_url, states_url])

    Total = get_object.Item(total)
    Total.rtrn_data()
    State = get_object.Item(state)
    State.rtrn_data()
    Country = get_object.Item(country)
    Country.rtrn_data()

    assert Total.deaths == data[total]['Deaths']
    assert State.deaths == data[state]['Deaths']
    assert Country.deaths == data[country]['Deaths']



import covid19_data

# example of how to get data by name
# .dataByName([string of item you want to find, can be any state, country, or total amount (spacing and capitalization do not matter)])
# object has three useful attributes: .deaths, .cases (.confirmed also works), and .recovered

total = covid19_data.dataByName("Total")  # create an object for our total data
china = covid19_data.dataByName("China")
US = covid19_data.dataByName("US")
new_york = covid19_data.dataByName("NewYork")
print(total.deaths, china.recovered, US.cases)

# example of how to get data by abbreviated name
# .dataByNameShort([two letter string of item you want to find, can be any state (spacing and capitalization do not matter)])
# object has three useful attributes: .deaths, .cases (.confirmed also works), and .recovered

texas = covid19_data.dataByNameShort("TX")  # create an object for our total data
california = covid19_data.dataByNameShort("CA")
new_york = covid19_data.dataByNameShort("NY")
print(texas.cases, california.deaths, new_york.cases)



from covid19_data.JHU import dataByCallerName, dataByCallerNameShort, dataByName, dataByNameShort, jsonByCallerName, \
    jsonByCallerNameShort, jsonByName, jsonByNameShort
from covid19_data import JHU



import covid19_data

# example of how to get json by name
# .jsonByName([string of item you want to find, can be any state, country, or total amount (spacing and capitalization do not matter)])
# object has three useful attributes: .deaths, .cases (.confirmed also works), and .recovered

total = covid19_data.jsonByName("Total")  # create an object for our total data
china = covid19_data.jsonByName("China")
US = covid19_data.jsonByName("US")
new_york = covid19_data.jsonByName("NewYork")
print(total, china, US, new_york)

# example of how to get json by abbreviated name
# .jsonByNameShort([two letter string of item you want to find, can be any state (spacing and capitalization do not matter)])
# object has three useful attributes: .deaths, .cases (.confirmed also works), and .recovered

texas = covid19_data.jsonByNameShort("TX")  # create an object for our total data
california = covid19_data.jsonByNameShort("CA")
new_york = covid19_data.jsonByNameShort("NY")
print(texas, california, new_york)



from .get_data import get_all_data
from .get_object import Item, Items
from covid19_data.dict_as_attribute import DictAsObj as DictToObj
import inspect
import re

states = {
    'AK': 'Alaska',
    'AL': 'Alabama',
    'AR': 'Arkansas',
    'AS': 'AmericanSamoa',
    'AZ': 'Arizona',
    'CA': 'California',
    'CO': 'Colorado',
    'CT': 'Connecticut',
    'DC': 'DistrictOfColumbia',
    'DE': 'Delaware',
    'FL': 'Florida',
    'GA': 'Georgia',
    'GU': 'Guam',
    'HI': 'Hawaii',
    'IA': 'Iowa',
    'ID': 'Idaho',
    'IL': 'Illinois',
    'IN': 'Indiana',
    'KS': 'Kansas',
    'KY': 'Kentucky',
    'LA': 'Louisiana',
    'MA': 'Massachusetts',
    'MD': 'Maryland',
    'ME': 'Maine',
    'MI': 'Michigan',
    'MN': 'Minnesota',
    'MO': 'Missouri',
    'MP': 'NorthernMarianaIslands',
    'MS': 'Mississippi',
    'MT': 'Montana',
    'NC': 'NorthCarolina',
    'ND': 'NorthDakota',
    'NE': 'Nebraska',
    'NH': 'NewHampshire',
    'NJ': 'NewJersey',
    'NM': 'NewMexico',
    'NV': 'Nevada',
    'NY': 'NewYork',
    'OH': 'Ohio',
    'OK': 'Oklahoma',
    'OR': 'Oregon',
    'PA': 'Pennsylvania',
    'PR': 'PuertoRico',
    'RI': 'RhodeIsland',
    'SC': 'SouthCarolina',
    'SD': 'SouthDakota',
    'TN': 'Tennessee',
    'TX': 'Texas',
    'UT': 'Utah',
    'VA': 'Virginia',
    'VI': 'VirginIslands',
    'VT': 'Vermont',
    'WA': 'Washington',
    'WI': 'Wisconsin',
    'WV': 'WestVirginia',
    'WY': 'Wyoming'
}
countries = [
    "Australia",
    "Austria",
    "Canada",
    "China",
    "Denmark",
    "Finland",
    "France",
    "Germany",
    "Iceland",
    "Ireland",
    "Italy",
    "Netherlands",
    "Norway",
    "Russia",
    "Sweden",
    "Switzerland",
    "UnitedKingdom",
    "US",
    "Spain",
    "Mexico",
    "Chile",
    "Brazil",
    "Peru",
    "Colombia",
    "Japan",
    "Ukraine",
    "India",
    "Pakistan",
    "Afghanistan",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "AntiguaAndBarbuda",
    "Argentina",
    "Armenia",
    "Azerbaijan",
    "Bahamas",
    "Bahrain",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bhutan",
    "Bolivia",
    "BosniaAndHerzegovina",
    "Botswana",
    "Brunei",
    "Bulgaria",
    "BurkinaFaso",
    "Burma",
    "Burundi",
    "CaboVerde",
    "Cambodia",
    "Cameroon",
    "CentralAfricanRepublic",
    "Chad",
    "Comoros",
    "CongoBrazzaville",
    "CongoKinshasa",
    "CostaRica",
    "CotedIvoire",
    "Croatia",
    "Cuba",
    "Cyprus",
    "Czechia",
    "DiamondPrincess",
    "Djibouti",
    "Dominica",
    "DominicanRepublic",
    "Ecuador",
    "Egypt",
    "ElSalvador",
    "EquatorialGuinea",
    "Eritrea",
    "Estonia",
    "Eswatini",
    "Ethiopia",
    "Fiji",
    "Gabon",
    "Gambia",
    "Georgia",
    "Ghana",
    "Greece",
    "Grenada",
    "Guatemala",
    "Guinea",
    "GuineaBissau",
    "Guyana",
    "Haiti",
    "HolySee",
    "Honduras",
    "Hungary",
    "Indonesia",
    "Iran",
    "Iraq",
    "Israel",
    "Jamaica",
    "Jordan",
    "Kazakhstan",
    "Kenya",
    "KoreaSouth",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "MsZaandam",
    "Madagascar",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Mauritania",
    "Mauritius",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nepal",
    "NewZealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "NorthMacedonia",
    "Oman",
    "Panama",
    "PapuaNewGuinea",
    "Paraguay",
    "Philippines",
    "Poland",
    "Portugal",
    "Qatar",
    "Romania",
    "Rwanda",
    "SaintKittsAndNevis",
    "SaintLucia",
    "SaintVincentAndTheGrenadines",
    "SanMarino",
    "SaoTomeAndPrincipe",
    "SaudiArabia",
    "Senegal",
    "Serbia",
    "Seychelles",
    "SierraLeone",
    "Singapore",
    "Slovakia",
    "Slovenia",
    "Somalia",
    "SouthAfrica",
    "SouthSudan",
    "SriLanka",
    "Sudan",
    "Suriname",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "TimorLeste",
    "Togo",
    "TrinidadAndTobago",
    "Tunisia",
    "Turkey",
    "Uganda",
    "UnitedArabEmirates",
    "Uruguay",
    "Uzbekistan",
    "Venezuela",
    "Vietnam",
    "WestBankAndGaza",
    "WesternSahara",
    "Yemen",
    "Zambia",
    "Zimbabwe"
]

remove_space = re.compile(r'\s+')

Australia = DictToObj({})
Austria = DictToObj({})
Canada = DictToObj({})
China = DictToObj({})
Denmark = DictToObj({})
Finland = DictToObj({})
France = DictToObj({})
Germany = DictToObj({})
Iceland = DictToObj({})
Ireland = DictToObj({})
Italy = DictToObj({})
Netherlands = DictToObj({})
Norway = DictToObj({})
Russia = DictToObj({})
Sweden = DictToObj({})
Switzerland = DictToObj({})
UnitedKingdom = DictToObj({})
Spain = DictToObj({})
Mexico = DictToObj({})
Chile = DictToObj({})
Brazil = DictToObj({})
Peru = DictToObj({})
Colombia = DictToObj({})
Japan = DictToObj({})
Ukraine = DictToObj({})
India = DictToObj({})
Pakistan = DictToObj({})
Afghanistan = DictToObj({})
Albania = DictToObj({})
Algeria = DictToObj({})
Andorra = DictToObj({})
Angola = DictToObj({})
AntiguaAndBarbuda = DictToObj({})
Argentina = DictToObj({})
Armenia = DictToObj({})
Azerbaijan = DictToObj({})
Bahamas = DictToObj({})
Bahrain = DictToObj({})
Bangladesh = DictToObj({})
Barbados = DictToObj({})
Belarus = DictToObj({})
Belgium = DictToObj({})
Belize = DictToObj({})
Benin = DictToObj({})
Bhutan = DictToObj({})
Bolivia = DictToObj({})
BosniaAndHerzegovina = DictToObj({})
Botswana = DictToObj({})
Brunei = DictToObj({})
Bulgaria = DictToObj({})
BurkinaFaso = DictToObj({})
Burma = DictToObj({})
Burundi = DictToObj({})
CaboVerde = DictToObj({})
Cambodia = DictToObj({})
Cameroon = DictToObj({})
CentralAfricanRepublic = DictToObj({})
Chad = DictToObj({})
Comoros = DictToObj({})
CongoBrazzaville = DictToObj({})
CongoKinshasa = DictToObj({})
CostaRica = DictToObj({})
CotedIvoire = DictToObj({})
Croatia = DictToObj({})
Cuba = DictToObj({})
Cyprus = DictToObj({})
Czechia = DictToObj({})
DiamondPrincess = DictToObj({})
Djibouti = DictToObj({})
Dominica = DictToObj({})
DominicanRepublic = DictToObj({})
Ecuador = DictToObj({})
Egypt = DictToObj({})
ElSalvador = DictToObj({})
EquatorialGuinea = DictToObj({})
Eritrea = DictToObj({})
Estonia = DictToObj({})
Eswatini = DictToObj({})
Ethiopia = DictToObj({})
Fiji = DictToObj({})
Gabon = DictToObj({})
Gambia = DictToObj({})
Ghana = DictToObj({})
Greece = DictToObj({})
Grenada = DictToObj({})
Guatemala = DictToObj({})
Guinea = DictToObj({})
GuineaBissau = DictToObj({})
Guyana = DictToObj({})
Haiti = DictToObj({})
HolySee = DictToObj({})
Honduras = DictToObj({})
Hungary = DictToObj({})
Indonesia = DictToObj({})
Iran = DictToObj({})
Iraq = DictToObj({})
Israel = DictToObj({})
Jamaica = DictToObj({})
Jordan = DictToObj({})
Kazakhstan = DictToObj({})
Kenya = DictToObj({})
KoreaSouth = DictToObj({})
Kosovo = DictToObj({})
Kuwait = DictToObj({})
Kyrgyzstan = DictToObj({})
Laos = DictToObj({})
Latvia = DictToObj({})
Lebanon = DictToObj({})
Lesotho = DictToObj({})
Liberia = DictToObj({})
Libya = DictToObj({})
Liechtenstein = DictToObj({})
Lithuania = DictToObj({})
Luxembourg = DictToObj({})
MSZaandam = DictToObj({})
Madagascar = DictToObj({})
Malawi = DictToObj({})
Malaysia = DictToObj({})
Maldives = DictToObj({})
Mali = DictToObj({})
Malta = DictToObj({})
Mauritania = DictToObj({})
Mauritius = DictToObj({})
Moldova = DictToObj({})
Monaco = DictToObj({})
Mongolia = DictToObj({})
Montenegro = DictToObj({})
Morocco = DictToObj({})
Mozambique = DictToObj({})
Namibia = DictToObj({})
Nepal = DictToObj({})
NewZealand = DictToObj({})
Nicaragua = DictToObj({})
Niger = DictToObj({})
Nigeria = DictToObj({})
NorthMacedonia = DictToObj({})
Oman = DictToObj({})
Panama = DictToObj({})
PapuaNewGuinea = DictToObj({})
Paraguay = DictToObj({})
Philippines = DictToObj({})
Poland = DictToObj({})
Portugal = DictToObj({})
Qatar = DictToObj({})
Romania = DictToObj({})
Rwanda = DictToObj({})
SaintKittsAndNevis = DictToObj({})
SaintLucia = DictToObj({})
SaintVincentAndTheGrenadines = DictToObj({})
SanMarino = DictToObj({})
SaoTomeAndPrincipe = DictToObj({})
SaudiArabia = DictToObj({})
Senegal = DictToObj({})
Serbia = DictToObj({})
Seychelles = DictToObj({})
SierraLeone = DictToObj({})
Singapore = DictToObj({})
Slovakia = DictToObj({})
Slovenia = DictToObj({})
Somalia = DictToObj({})
SouthAfrica = DictToObj({})
SouthSudan = DictToObj({})
SriLanka = DictToObj({})
Sudan = DictToObj({})
Suriname = DictToObj({})
Syria = DictToObj({})
Taiwan = DictToObj({})
Tajikistan = DictToObj({})
Tanzania = DictToObj({})
Thailand = DictToObj({})
TimorLeste = DictToObj({})
Togo = DictToObj({})
TrinidadAndTobago = DictToObj({})
Tunisia = DictToObj({})
Turkey = DictToObj({})
Uganda = DictToObj({})
UnitedArabEmirates = DictToObj({})
Uruguay = DictToObj({})
Uzbekistan = DictToObj({})
Venezuela = DictToObj({})
Vietnam = DictToObj({})
WestBankAndGaza = DictToObj({})
WesternSahara = DictToObj({})
Yemen = DictToObj({})
Zambia = DictToObj({})
Zimbabwe = DictToObj({})

Alaska = DictToObj({})
Alabama = DictToObj({})
Arkansas = DictToObj({})
AmericanSamoa = DictToObj({})
Arizona = DictToObj({})
California = DictToObj({})
Colorado = DictToObj({})
Connecticut = DictToObj({})
DistrictOfColumbia = DictToObj({})
Delaware = DictToObj({})
Florida = DictToObj({})
Georgia = DictToObj({})
Guam = DictToObj({})
Hawaii = DictToObj({})
Iowa = DictToObj({})
Idaho = DictToObj({})
Illinois = DictToObj({})
Indiana = DictToObj({})
Kansas = DictToObj({})
Kentucky = DictToObj({})
Louisiana = DictToObj({})
Massachusetts = DictToObj({})
Maryland = DictToObj({})
Maine = DictToObj({})
Michigan = DictToObj({})
Minnesota = DictToObj({})
Missouri = DictToObj({})
NorthernMarianaIslands = DictToObj({})
Mississippi = DictToObj({})
Montana = DictToObj({})
NorthCarolina = DictToObj({})
NorthDakota = DictToObj({})
Nebraska = DictToObj({})
NewHampshire = DictToObj({})
NewJersey = DictToObj({})
NewMexico = DictToObj({})
Nevada = DictToObj({})
NewYork = DictToObj({})
Ohio = DictToObj({})
Oklahoma = DictToObj({})
Oregon = DictToObj({})
Pennsylvania = DictToObj({})
PuertoRico = DictToObj({})
RhodeIsland = DictToObj({})
SouthCarolina = DictToObj({})
SouthDakota = DictToObj({})
Tennessee = DictToObj({})
Texas = DictToObj({})
Utah = DictToObj({})
Virginia = DictToObj({})
VirginIslands = DictToObj({})
Vermont = DictToObj({})
Washington = DictToObj({})
Wisconsin = DictToObj({})
WestVirginia = DictToObj({})
Wyoming = DictToObj({})


def dataByCallerName():
    s = str(inspect.stack()[1][4]).split()[0][2:]
    item = Item(s)
    item.rtrn_data()
    return item


def dataByCallerNameShort():
    s = str(inspect.stack()[1][4]).split()[0][2:]
    item = Item(states[s])
    item.rtrn_data()
    return item


def dataByName(_name):
    _name = re.sub(remove_space, '', _name).upper()
    item = Item(_name)
    item.rtrn_data()
    return item


def dataByNameShort(_name):
    _name = re.sub(remove_space, '', _name).upper()
    item = Item(states[_name].upper())
    item.rtrn_data()
    return item


def jsonByCallerName():
    s = str(inspect.stack()[1][4]).split()[0][2:]
    item = Item(s)
    item.rtrn_data()
    return item.json


def jsonByCallerNameShort():
    s = str(inspect.stack()[1][4]).split()[0][2:]
    item = Item(states[s])
    item.rtrn_data()
    return item.json


def jsonByName(_name):
    _name = re.sub(remove_space, '', _name).upper()
    item = Item(_name)
    item.rtrn_data()
    return item.json


def jsonByNameShort(_name):
    _name = re.sub(remove_space, '', _name).upper()
    item = Item(states[_name].upper())
    item.rtrn_data()
    return item.json


US_obj = dataByName("US")
us_dict = {
    "deaths": US_obj.deaths, "cases": US_obj.cases, "recovered": US_obj.recovered, "confirmed": US_obj.cases
}

total_obj = dataByName("Total")
total_dict = {
    "deaths": total_obj.deaths, "cases": total_obj.cases, "recovered": total_obj.recovered, "confirmed": total_obj.cases
}

for state in states:
    name = states[state]
    obj = dataByName(name)
    data_dict = {"deaths": obj.deaths,
                 "cases": obj.cases, "recovered": obj.recovered, "confirmed": obj.cases}
    globals()[name] = DictToObj(data_dict)

for country in countries:
    name = country
    obj = dataByName(name)
    data_dict = {"deaths": obj.deaths,
                 "cases": obj.cases, "recovered": obj.recovered, "confirmed": obj.cases}
    globals()[re.sub(remove_space, '', name)] = DictToObj(data_dict)

US = DictToObj(us_dict)
Total = DictToObj(total_dict)



import json
import urllib.request
import re
from threading import Thread
import os

doc = {}


def get_data(url):
    return json.loads(
        urllib.request.urlopen(urllib.request.Request(url, None, {'User-Agent': os.environ['useragent']})).read().decode())[
        'features']


def get_state(
        link='https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/ncov_cases/FeatureServer/1/query?where=Count'
             'ry_Region=%27US%27&outFields=Province_State,confirmed,deaths,recovered,%20active&resultRecordCount=200&f=pjson'):
    document = {'States': {}
                }
    for item in get_data(link):
        if 'Province_State' in item['attributes'].keys():
            stateprov = re.sub(re.compile('[^a-zA-Z]'), '', item['attributes']['Province_State'])
            del item['attributes']['Province_State']
            document['States'].update({stateprov.upper(): item['attributes']})
        else:
            pass
    doc.update(document)


def get_country(
        link='https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/ncov_cases/FeatureServer/2/query?where=1%3D1'
             '&objectIds=&time=&geometry=&geometryType=esriGeometryEnvelope&inSR=&spatialRel=esriSpatialRelIntersects&resultT'
             'ype=none&distance=0.0&units=esriSRUnit_Meter&returnGeodetic=false&outFields=+Country_Region%2C+confirmed%2C+dea'
             'ths%2C+recovered%2C+active&returnGeometry=false&featureEncoding=esriDefault&multipatchOption=xyFootprint&maxAll'
             'owableOffset=&geometryPrecision=&outSR=&datumTransformation=&applyVCSProjection=false&returnIdsOnly=false&retur'
             'nUniqueIdsOnly=false&returnCountOnly=false&returnExtentOnly=false&returnQueryGeometry=false&returnDistinctValue'
             's=false&cacheHint=false&orderByFields=&groupByFieldsForStatistics=&outStatistics=&having=&resultOffset=&resultR'
             'ecordCount=&returnZ=false&returnM=false&returnExceededLimitFeatures=true&quantizationParameters=&sqlFormat=none'
             '&f=pjson&token='):
    document = {'Countries': {},
                }
    for item in get_data(link):
        if 'Country_Region' in item['attributes'].keys():
            country = re.sub(re.compile('[^a-zA-Z]'), '', item['attributes']['Country_Region'])
            del item['attributes']['Country_Region']
            document['Countries'].update({country.upper(): item['attributes']})
        else:
            pass
    doc.update(document)


def get_total(
        link='https://services1.arcgis.com/0MSEUqKaxRlEPj5g/ArcGIS/rest/services/Coronavirus_2019_nCoV_Cases/FeatureServer/1/'
             'query?where=1%3D1&objectIds=&time=&geometry=&geometryType=esriGeometryEnvelope&inSR=&spatialRel=esriSpatialRelI'
             'ntersects&resultType=none&distance=0.0&units=esriSRUnit_Meter&returnGeodetic=false&outFields=&returnGeometry=tr'
             'ue&featureEncoding=esriDefault&multipatchOption=xyFootprint&maxAllowableOffset=&geometryPrecision=&outSR=&datum'
             'Transformation=&applyVCSProjection=false&returnIdsOnly=false&returnUniqueIdsOnly=false&returnCountOnly=false&re'
             'turnExtentOnly=false&returnQueryGeometry=false&returnDistinctValues=false&cacheHint=false&orderByFields=&groupB'
             'yFieldsForStatistics=&outStatistics=%5B%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticField%22%3A%22Confirm'
             'ed%22%2C%22outStatisticFieldName%22%3A%22Confirmed%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%22onStatisticF'
             'ield%22%3A%22Deaths%22%2C%22outStatisticFieldName%22%3A%22Deaths%22%7D%2C%7B%22statisticType%22%3A%22sum%22%2C%'
             '22onStatisticField%22%3A%22Recovered%22%2C%22outStatisticFieldName%22%3A%22Recovered%22%7D%5D&having=&resultOff'
             'set=&resultRecordCount=&returnZ=false&returnM=false&returnExceededLimitFeatures=true&quantizationParameters=&sq'
             'lFormat=none&f=pjson&token='):
    document = {}
    for item in get_data(link):
        if 'Country_Region' not in item['attributes'].keys() and 'Province_State' not in item['attributes'].keys():
            document.update({'TOTAL': item['attributes']})
        else:
            pass
    doc.update(document)


def lambda_handler(event, context):
    t1 = Thread(target=get_state)
    t2 = Thread(target=get_country)
    t3 = Thread(target=get_total)

    t1.start()
    t2.start()
    t3.start()

    t1.join()
    t2.join()
    t3.join()
    return doc



from covid19_data import JHU

# Format: <Data Source>.<Location>.<Statistic>
# For example to get data from John Hopkins University, review the following example:
# JHU.China.deaths

print("The number of COVID-19 recoveries in the US: " + str(JHU.US.recovered))
print("The number of confirmed COVID-19 cases in Texas: " + str(JHU.Texas.confirmed))
print("The number of COVID-19 deaths in California: " + str(JHU.California.deaths))
print("The number of worldwide COVID-19 deaths: " + str(JHU.Total.deaths))
print("The number of COVID-19 deaths in China: " + str(JHU.China.deaths))
print("The number of COVID-19 deaths in UK: " + str(JHU.UnitedKingdom.deaths))
